/************************************************************************
 * Copyright (c) 2010 by SAS Institute Inc., Cary, NC, USA.            	*
 *                                                                     	*
 * NAME:          csb_post_init_application                             *
 *                                                                     	*
 * PURPOSE:       Called at the end of solution init after the SASAUTOS	*
 *                macro path has been set up. Performs any other       	*
 *                customer-specific initialization during startup.     	*
 *                This sets the log path for a particular user session	*
 *                             	                                        *	
 *                                                                     	*
 * USAGE:         %csb_post_init_application(VERSION=)                  *
 *                                                                     	*
 * PARAMETERS:    VERSION     The product version number               	*
 *                            that was passed to solution init files   	*
 *                                                                     	*
 ***********************************************************************/
%macro csb_post_init_application(VERSION=);

%global csb_config_dir log_path_cs csb_app_user dcreate_status;
%local rc dt;
/* Edit this line for crslog_root */
%get_swc_property(propertyName=csb.config.dir,q_rd_swc=&CSB_SRVR_SWC.,outvar=csb_config_dir);
%let crslog_root = &csb_config_dir./AppData/&CSB_CONFIG_FOLDER_NM./&CSB_VERSION./logs;

/* Checking if crslog_root resolves to a valid path */
%let rc = %sysfunc(filename(fref,&crslog_root));

%let log_path_cs  = %superq(crslog_root);

%if &rc = 0 and %symexist(_metauser) %then %do;

  /* Creating user specific directory */
  %let csb_app_user = %scan(&_metauser,1,@);
  %csbmva_create_dir(path = &log_path_cs,dirname = &csb_app_user,status_var = dcreate_status);
  %if %quote(&dcreate_status) eq %then %do;
	%put ERROR: User does not have permission to create logs;
    %abort ABEND;
  %end;
  %else %do;
    %let log_path_cs  = &log_path_cs./&csb_app_user;
  %end;

  /* Creating directory for current date*/
  %let dt = %sysfunc(today(),yymmdd10.);
  %let dt = %superq(dt);
  %csbmva_create_dir(path = &log_path_cs,dirname = &dt,status_var = dcreate_status);
  %if %quote(&dcreate_status) eq %then %do;
	%put ERROR: User does not have permission to create logs;
    %abort ABEND;
  %end;
  %else %do;
    %let log_path_cs  = &log_path_cs./&dt/;
  %end;

  %let log_path_cs = %superq(log_path_cs);
  %put &log_path_cs;

%end;

%mend csb_post_init_application;
